@@ -183,18 +183,6 @@ class TestNodeWaitForProvisionState(base.TestCase):
                                self.node.wait_for_provision_state,
                                self.session, 'manageable')
 
-    def test_failure_error(self, mock_fetch):
-        def _get_side_effect(_self, session):
-            self.node.provision_state = 'error'
-            self.assertIs(session, self.session)
-
-        mock_fetch.side_effect = _get_side_effect
-
-        self.assertRaisesRegex(exceptions.ResourceFailure,
-                               'failure state "error"',
-                               self.node.wait_for_provision_state,
-                               self.session, 'manageable')
-
     def test_enroll_as_failure(self, mock_fetch):
         def _get_side_effect(_self, session):
             self.node.provision_state = 'enroll'
@@ -309,7 +297,8 @@ class TestNodeCreate(base.TestCase):
         self.assertIs(result, self.node)
         self.session.post.assert_called_once_with(
             mock.ANY, json={'driver': FAKE['driver']},
-            headers=mock.ANY, microversion=self.session.default_microversion)
+            headers=mock.ANY, microversion=self.session.default_microversion,
+            params={})
         self.assertFalse(mock_prov.called)
 
     def test_available_new_version(self, mock_prov):
@@ -325,7 +314,8 @@ class TestNodeCreate(base.TestCase):
         self.assertIs(result, self.node)
         self.session.post.assert_called_once_with(
             mock.ANY, json={'driver': FAKE['driver']},
-            headers=mock.ANY, microversion=self.session.default_microversion)
+            headers=mock.ANY, microversion=self.session.default_microversion,
+            params={})
         mock_prov.assert_has_calls([
             mock.call(self.node, self.session, 'manage', wait=True),
             mock.call(self.node, self.session, 'provide', wait=True)
@@ -347,7 +337,8 @@ class TestNodeCreate(base.TestCase):
         self.assertIs(result, self.node)
         self.session.post.assert_called_once_with(
             mock.ANY, json={'driver': FAKE['driver']},
-            headers=mock.ANY, microversion=self.session.default_microversion)
+            headers=mock.ANY, microversion=self.session.default_microversion,
+            params={})
         self.assertFalse(mock_prov.called)
 
     def test_no_manageable_in_old_version(self, mock_prov):
@@ -366,7 +357,8 @@ class TestNodeCreate(base.TestCase):
         self.assertIs(result, self.node)
         self.session.post.assert_called_once_with(
             mock.ANY, json={'driver': FAKE['driver']},
-            headers=mock.ANY, microversion=self.session.default_microversion)
+            headers=mock.ANY, microversion=self.session.default_microversion,
+            params={})
         mock_prov.assert_called_once_with(self.node, self.session, 'manage',
                                           wait=True)
 
@@ -379,7 +371,8 @@ class TestNodeCreate(base.TestCase):
         self.assertIs(result, self.node)
         self.session.post.assert_called_once_with(
             mock.ANY, json={'driver': FAKE['driver']},
-            headers=mock.ANY, microversion=self.session.default_microversion)
+            headers=mock.ANY, microversion=self.session.default_microversion,
+            params={})
         mock_prov.assert_called_once_with(self.node, self.session, 'manage',
                                           wait=True)
 
